@@ -5,17 +5,15 @@ import logging
 import re
 from contextlib import asynccontextmanager
 from datetime import datetime, timedelta
-from typing import Any, AsyncGenerator
+from typing import TYPE_CHECKING
 
 import pytz
 from dateutil import tz
 from ddtrace import tracer
-from discord.channel import VoiceChannel
 
-from .. import SpellBot
-from ..database import db_session_manager, rollback_session
-from ..metrics import add_span_error, setup_ignored_errors
-from ..operations import (
+from spellbot.database import db_session_manager, rollback_session
+from spellbot.metrics import add_span_error, setup_ignored_errors
+from spellbot.operations import (
     bot_can_delete_channel,
     safe_delete_channel,
     safe_delete_message,
@@ -23,11 +21,19 @@ from ..operations import (
     safe_get_partial_message,
     safe_update_embed,
 )
-from ..services import GamesService, ServicesRegistry
-from ..settings import Settings
+from spellbot.services import GamesService, ServicesRegistry
+from spellbot.settings import settings
+
 from .base_action import handle_exception
 
-settings = Settings()
+if TYPE_CHECKING:
+    from collections.abc import AsyncGenerator
+
+    from discord.channel import VoiceChannel
+
+    from spellbot import SpellBot
+    from spellbot.models import GameDict
+
 logger = logging.getLogger(__name__)
 
 
@@ -99,7 +105,7 @@ class TasksAction:
             await self.delete_channels(channels)
         except BaseException as e:  # Catch EVERYTHING so tasks don't die
             add_span_error(e)
-            logger.exception("error: exception in background task: %s", e)
+            logger.exception("error: exception in background task")
             await rollback_session()
 
     async def gather_channels(self) -> list[VoiceChannel]:
@@ -134,15 +140,13 @@ class TasksAction:
         return channels
 
     async def delete_channels(self, channels: list[VoiceChannel]) -> None:
-        batch = 0
-        for channel in sorted(channels, key=lambda c: c.created_at):
+        for batch, channel in enumerate(sorted(channels, key=lambda c: c.created_at)):
             logger.info("deleting channel %s(%s)", channel.name, channel.id)
             await safe_delete_channel(channel, channel.guild.id)
             await asyncio.sleep(5)
 
             # Try to avoid rate limiting by the Discord API
-            batch += 1
-            if batch > settings.VOICE_CLEANUP_BATCH:
+            if batch + 1 > settings.VOICE_CLEANUP_BATCH:
                 remaining = len(channels) - settings.VOICE_CLEANUP_BATCH
                 logger.info("batch limit reached, %s channels remain", remaining)
                 break
@@ -154,16 +158,16 @@ class TasksAction:
             await self.expire_games(games)
         except BaseException as e:  # Catch EVERYTHING so tasks don't die
             add_span_error(e)
-            logger.exception("error: exception in background task: %s", e)
+            logger.exception("error: exception in background task")
             await rollback_session()
 
-    async def expire_games(self, games: list[dict[str, Any]]) -> None:
+    async def expire_games(self, games: list[GameDict]) -> None:
         batch = 0
         for game in games:
             game_id = game["id"]
             logger.info("expiring game %s...", game_id)
-            await self.services.games.delete_games([game_id])
-            await self.expire_game(game)
+            dequeued = await self.services.games.delete_games([game_id])
+            await self.expire_game(game, dequeued)
 
             batch += 1
             if batch >= 5:  # pragma: no cover
@@ -172,27 +176,26 @@ class TasksAction:
             else:
                 await asyncio.sleep(1)
 
-    async def expire_game(self, game: dict[str, Any]) -> None:
-        message_xid = game["message_xid"]
-        if message_xid is None:
-            return
+    async def expire_game(self, game: GameDict, dequeued: int) -> None:
+        for post in game.get("posts", []):
+            guild_xid = post["guild_xid"]
+            channel_xid = post["channel_xid"]
+            message_xid = post["message_xid"]
 
-        guild_xid = game["guild_xid"]
-        channel_xid = game["channel_xid"]
-        chan = await safe_fetch_text_channel(self.bot, guild_xid, channel_xid)
-        if not chan:
-            return
+            chan = await safe_fetch_text_channel(self.bot, guild_xid, channel_xid)
+            if not chan:
+                continue
 
-        if not (post := safe_get_partial_message(chan, guild_xid, message_xid)):
-            return
+            if not (post := safe_get_partial_message(chan, guild_xid, message_xid)):
+                continue
 
-        channel_data = await self.services.channels.select(channel_xid)
-        if channel_data and channel_data["delete_expired"]:
-            await safe_delete_message(post)
-        else:
-            await safe_update_embed(
-                post,
-                content="Sorry, this game was expired due to inactivity.",
-                embed=None,
-                view=None,
-            )
+            channel_data = await self.services.channels.select(channel_xid)
+            if not dequeued or channel_data and channel_data["delete_expired"]:
+                await safe_delete_message(post)
+            else:
+                await safe_update_embed(
+                    post,
+                    content="Sorry, this game was expired due to inactivity.",
+                    embed=None,
+                    view=None,
+                )
