@@ -1,6 +1,4 @@
-# pylint: disable=too-many-arguments
 import logging
-from typing import Optional
 
 import discord
 from ddtrace import tracer
@@ -8,10 +6,12 @@ from discord import app_commands
 from discord.app_commands import Choice
 from discord.ext import commands
 
-from .. import SpellBot
-from ..actions import AdminAction
-from ..metrics import add_span_context
-from ..utils import for_all_callbacks, is_admin, is_guild
+from spellbot import SpellBot
+from spellbot.actions import AdminAction
+from spellbot.enums import GameFormat, GameService
+from spellbot.metrics import add_span_context
+from spellbot.settings import settings
+from spellbot.utils import for_all_callbacks, is_admin, is_guild
 
 logger = logging.getLogger(__name__)
 
@@ -45,7 +45,7 @@ class AdminCog(commands.Cog):
     )
     @app_commands.describe(message="Message content")
     @tracer.wrap(name="interaction", resource="set_motd")
-    async def motd(self, interaction: discord.Interaction, message: Optional[str] = None) -> None:
+    async def motd(self, interaction: discord.Interaction, message: str | None = None) -> None:
         add_span_context(interaction)
         async with AdminAction.create(self.bot, interaction) as action:
             await action.set_motd(message)
@@ -58,7 +58,7 @@ class AdminCog(commands.Cog):
     async def channel_motd(
         self,
         interaction: discord.Interaction,
-        message: Optional[str] = None,
+        message: str | None = None,
     ) -> None:
         add_span_context(interaction)
         async with AdminAction.create(self.bot, interaction) as action:
@@ -72,7 +72,7 @@ class AdminCog(commands.Cog):
     async def channel_extra(
         self,
         interaction: discord.Interaction,
-        message: Optional[str] = None,
+        message: str | None = None,
     ) -> None:
         add_span_context(interaction)
         async with AdminAction.create(self.bot, interaction) as action:
@@ -84,7 +84,7 @@ class AdminCog(commands.Cog):
     )
     @app_commands.describe(page="If there are multiple pages of output, which one?")
     @tracer.wrap(name="interaction", resource="channels")
-    async def channels(self, interaction: discord.Interaction, page: Optional[int] = 1) -> None:
+    async def channels(self, interaction: discord.Interaction, page: int | None = 1) -> None:
         add_span_context(interaction)
         async with AdminAction.create(self.bot, interaction) as action:
             page = page or 1
@@ -93,7 +93,7 @@ class AdminCog(commands.Cog):
     @app_commands.command(name="awards", description="Setup player awards on your server.")
     @app_commands.describe(page="If there are multiple pages of output, which one?")
     @tracer.wrap(name="interaction", resource="awards")
-    async def awards(self, interaction: discord.Interaction, page: Optional[int] = 1) -> None:
+    async def awards(self, interaction: discord.Interaction, page: int | None = 1) -> None:
         add_span_context(interaction)
         async with AdminAction.create(self.bot, interaction) as action:
             page = page or 1
@@ -116,10 +116,10 @@ class AdminCog(commands.Cog):
         count: int,
         role: discord.Role,
         message: str,
-        repeating: Optional[bool] = False,
-        remove: Optional[bool] = False,
-        verified_only: Optional[bool] = False,
-        unverified_only: Optional[bool] = False,
+        repeating: bool | None = False,
+        remove: bool | None = False,
+        verified_only: bool | None = False,
+        unverified_only: bool | None = False,
     ) -> None:
         add_span_context(interaction)
         async with AdminAction.create(self.bot, interaction) as action:
@@ -162,6 +162,34 @@ class AdminCog(commands.Cog):
         async with AdminAction.create(self.bot, interaction) as action:
             await action.set_default_seats(seats)
 
+    @set_group.command(
+        name="default_format",
+        description="Set the default game format for new games in this channel.",
+    )
+    @app_commands.describe(format="Default game format")
+    @app_commands.choices(
+        format=[Choice(name=str(format), value=format.value) for format in GameFormat],
+    )
+    @tracer.wrap(name="interaction", resource="set_default_format")
+    async def default_format(self, interaction: discord.Interaction, format: int) -> None:
+        add_span_context(interaction)
+        async with AdminAction.create(self.bot, interaction) as action:
+            await action.set_default_format(format)
+
+    @set_group.command(
+        name="default_service",
+        description="Set the default game service for new games in this channel.",
+    )
+    @app_commands.describe(service="Default service")
+    @app_commands.choices(
+        service=[Choice(name=str(service), value=service.value) for service in GameService],
+    )
+    @tracer.wrap(name="interaction", resource="set_default_service")
+    async def default_service(self, interaction: discord.Interaction, service: int) -> None:
+        add_span_context(interaction)
+        async with AdminAction.create(self.bot, interaction) as action:
+            await action.set_default_service(service)
+
     @set_group.command(
         name="auto_verify",
         description="Should posting in this channel automatically verify users?",
@@ -236,6 +264,50 @@ class AdminCog(commands.Cog):
         async with AdminAction.create(self.bot, interaction) as action:
             await action.set_show_points(setting)
 
+    @set_group.command(
+        name="require_confirmation",
+        description="Set the option for requiring points confirmation on games in this channel.",
+    )
+    @app_commands.describe(setting="Setting")
+    @tracer.wrap(name="interaction", resource="set_require_confirmation")
+    async def require_confirmation(self, interaction: discord.Interaction, setting: bool) -> None:
+        add_span_context(interaction)
+        async with AdminAction.create(self.bot, interaction) as action:
+            await action.set_require_confirmation(setting)
+
+    @set_group.command(
+        name="voice_invite",
+        description="Set the option for voice invite creation on games in this channel.",
+    )
+    @app_commands.describe(setting="Setting")
+    @tracer.wrap(name="interaction", resource="set_voice_invite")
+    async def voice_invite(self, interaction: discord.Interaction, setting: bool) -> None:
+        add_span_context(interaction)
+        async with AdminAction.create(self.bot, interaction) as action:
+            await action.set_voice_invite(setting)
+
+    @app_commands.command(name="move_user", description="Move one user's data to another user.")
+    @tracer.wrap(name="interaction", resource="move_user")
+    @app_commands.describe(from_user_id="User ID of the old user")
+    @app_commands.describe(to_user_id="User ID of the new user")
+    async def move_user(
+        self,
+        interaction: discord.Interaction,
+        from_user_id: str,
+        to_user_id: str,
+    ) -> None:  # pragma: no cover
+        add_span_context(interaction)
+        assert interaction.guild_id is not None
+        # note: no user input validation is being done here
+        from_user_xid = int(from_user_id)
+        to_user_xid = int(to_user_id)
+        async with AdminAction.create(self.bot, interaction) as action:
+            await action.move_user(
+                guild_xid=interaction.guild_id,
+                from_user_xid=from_user_xid,
+                to_user_xid=to_user_xid,
+            )
+
 
 async def setup(bot: SpellBot) -> None:  # pragma: no cover
-    await bot.add_cog(AdminCog(bot), guild=bot.settings.GUILD_OBJECT)
+    await bot.add_cog(AdminCog(bot), guild=settings.GUILD_OBJECT)
