@@ -1,15 +1,15 @@
 import logging
-from typing import Optional
 
 import discord
 from ddtrace import tracer
 from discord import app_commands
 from discord.ext import commands
 
-from .. import SpellBot
-from ..actions import ScoreAction
-from ..metrics import add_span_context
-from ..utils import for_all_callbacks, is_guild
+from spellbot import SpellBot
+from spellbot.actions import ScoreAction
+from spellbot.metrics import add_span_context
+from spellbot.settings import settings
+from spellbot.utils import for_all_callbacks, is_guild
 
 logger = logging.getLogger(__name__)
 
@@ -28,7 +28,7 @@ class ScoreCog(commands.Cog):
     async def score(
         self,
         interaction: discord.Interaction,
-        user: Optional[discord.Member] = None,
+        user: discord.User | discord.Member | None = None,
     ) -> None:
         add_span_context(interaction)
         async with ScoreAction.create(self.bot, interaction) as action:
@@ -60,4 +60,4 @@ class ScoreCog(commands.Cog):
 
 
 async def setup(bot: SpellBot) -> None:  # pragma: no cover
-    await bot.add_cog(ScoreCog(bot), guild=bot.settings.GUILD_OBJECT)
+    await bot.add_cog(ScoreCog(bot), guild=settings.GUILD_OBJECT)
