@@ -1,15 +1,15 @@
 import logging
-from typing import Union
 
 import discord
 from ddtrace import tracer
 from discord import app_commands
 from discord.ext import commands
 
-from .. import SpellBot
-from ..actions import VerifyAction
-from ..metrics import add_span_context
-from ..utils import for_all_callbacks, is_admin, is_guild
+from spellbot import SpellBot
+from spellbot.actions import VerifyAction
+from spellbot.metrics import add_span_context
+from spellbot.settings import settings
+from spellbot.utils import for_all_callbacks, is_admin, is_guild
 
 logger = logging.getLogger(__name__)
 
@@ -26,7 +26,7 @@ class VerifyCog(commands.Cog):
     async def verify(
         self,
         interaction: discord.Interaction,
-        target: Union[discord.User, discord.Member],
+        target: discord.User | discord.Member,
     ) -> None:
         add_span_context(interaction)
         async with VerifyAction.create(self.bot, interaction) as action:
@@ -38,7 +38,7 @@ class VerifyCog(commands.Cog):
     async def unverify(
         self,
         interaction: discord.Interaction,
-        target: Union[discord.User, discord.Member],
+        target: discord.User | discord.Member,
     ) -> None:
         add_span_context(interaction)
         async with VerifyAction.create(self.bot, interaction) as action:
@@ -46,4 +46,4 @@ class VerifyCog(commands.Cog):
 
 
 async def setup(bot: SpellBot) -> None:  # pragma: no cover
-    await bot.add_cog(VerifyCog(bot), guild=bot.settings.GUILD_OBJECT)
+    await bot.add_cog(VerifyCog(bot), guild=settings.GUILD_OBJECT)
