@@ -84,6 +84,11 @@ class GuildsService:
         assert self.guild
         return cast(bool, self.guild.voice_create)
 
+    @sync_to_async()
+    def get_use_max_bitrate(self) -> bool:
+        assert self.guild
+        return cast(bool, self.guild.use_max_bitrate)
+
     @sync_to_async()
     def set_motd(self, message: str | None = None) -> None:
         if message:
@@ -105,6 +110,12 @@ class GuildsService:
         self.guild.voice_create = not self.guild.voice_create
         DatabaseSession.commit()
 
+    @sync_to_async()
+    def toggle_use_max_bitrate(self) -> None:
+        assert self.guild
+        self.guild.use_max_bitrate = not self.guild.use_max_bitrate
+        DatabaseSession.commit()
+
     @sync_to_async()
     def current_name(self) -> str:
         assert self.guild
