@@ -1,9 +1,10 @@
 from __future__ import annotations
 
 import logging
-from asyncio.events import AbstractEventLoop as Loop
+from contextlib import suppress
 from datetime import datetime, timedelta
 from pathlib import Path
+from typing import TYPE_CHECKING
 
 import aiohttp_jinja2
 import jinja2
@@ -11,10 +12,13 @@ import pytz
 from aiohttp import web
 from babel.dates import format_datetime
 
-from ..database import initialize_connection
-from ..models import import_models
-from ..settings import Settings
-from ..web.api import ping, record
+from spellbot.database import initialize_connection
+from spellbot.models import import_models
+from spellbot.settings import settings
+from spellbot.web.api import ping, record
+
+if TYPE_CHECKING:
+    from asyncio.events import AbstractEventLoop as Loop
 
 logger = logging.getLogger(__name__)
 
@@ -23,10 +27,8 @@ TEMPLATES_ROOT = Path(__file__).resolve().parent / "templates"
 
 def humanize(ts: int, offset: int, zone: str) -> str:
     d = datetime.fromtimestamp(ts / 1e3, tz=pytz.UTC) - timedelta(minutes=offset)
-    try:
+    with suppress(pytz.UnknownTimeZoneError):
         d = d.replace(tzinfo=pytz.timezone(zone))
-    except pytz.UnknownTimeZoneError:
-        pass
     return format_datetime(d, format="long")
 
 
@@ -48,11 +50,7 @@ def build_web_app() -> web.Application:
     return app
 
 
-def launch_web_server(
-    settings: Settings,
-    loop: Loop,
-    port: int,
-) -> None:  # pragma: no cover
+def launch_web_server(loop: Loop, port: int) -> None:  # pragma: no cover
     app = build_web_app()
     runner = web.AppRunner(app)
     loop.run_until_complete(runner.setup())
